@@ -13,6 +13,7 @@
 
 #include "ractiondef.h"
 #include "reventdef.h"
+#include "rdimdlg.h"
 
 class QMouseEvent;
 class QKeyEvent;
@@ -20,6 +21,7 @@ class RGraphic;
 class RInputPanel;
 class RSnap;
 class RStatusPanel;
+class RDimDlg;
 
 
 class RAction : public QObject
@@ -35,6 +37,7 @@ public:
   RSnap* snapper();
   RStatusPanel* statusPanel();
   RInputPanel* inputPanel();
+  RDimDlg* dimensionDlg();
 
 };
 
