@@ -11,10 +11,10 @@
 #define RATTRIBDIALOG_H
 
 #include <qdialog.h>
+#include <qlabel.h>
 #include <qtooltip.h>
 #include <qpushbutton.h>
 
-#include "rlabel.h"
 #include "rcombobox.h"
 
 #define DEF_ATTRIBDLG_WIDTH  256
@@ -27,8 +27,8 @@
 class RAttribDialog : public QDialog  {
   Q_OBJECT
 public: 
-	RAttribDialog(const char* _caption,
-	              const char* _label,
+	RAttribDialog(const QString& _caption,
+	              const QString& _label,
                 QWidget* _parent=0);
 
 	~RAttribDialog();
@@ -43,7 +43,7 @@ private:
   QPushButton* bCancel;
   QPushButton* bHelp;
 
-  RLabel*      lText;
+  QLabel*      lText;
   RComboBox*   cbColor;
   RComboBox*   cbWidth;
   RComboBox*   cbStyle;
