@@ -31,19 +31,19 @@ RButtonGroup::RButtonGroup(QWidget* _parent,
                            const char* _name)
 :QButtonGroup(_parent, _name)
 {
-  setFont(QFont("helvetica", RCONFIG->getSettingInt("Application:FontSize0")));
+  setFont( RCONFIG->getFont(0) );
 }
 
 
 
 // Constructor:
 //
-RButtonGroup::RButtonGroup(const char* _title,
+RButtonGroup::RButtonGroup(const QString& _title,
                            QWidget* _parent,
                            const char* _name)
 :QButtonGroup(_title, _parent, _name)
 {
-  setFont(QFont("helvetica", RCONFIG->getSettingInt("Application:FontSize0")));
+  setFont( RCONFIG->getFont(0) );
 }
 
 
