@@ -35,7 +35,7 @@ public:
       \param _parent The parent widget
       \param _name Name
   */
-  RButtonGroup(const char* _title, QWidget* _parent=0, const char* _name=0);
+  RButtonGroup(const QString& _title, QWidget* _parent=0, const char* _name=0);
   /*! Destructor
   */
   ~RButtonGroup();
