@@ -22,7 +22,6 @@
 #include "rfile.h"
 #include "rfonts.h"
 #include "rgraphic.h"
-#include "rconfig.h"
 #include "rlayer.h"
 #include "rlog.h"
 #include "rstring.h"
@@ -67,7 +66,6 @@ RComboBox::RComboBox(QWidget* _parent, const char* _name)
 :QComboBox(_parent, _name)
 {
   readWrite=true;
-  setFont(QFont("helvetica", RCONFIG->getSettingInt("Application:FontSize0")));
 }
 
 
@@ -77,7 +75,6 @@ RComboBox::RComboBox(bool _rw, QWidget* _parent, const char* _name)
 :QComboBox(_rw, _parent, _name)
 {
   readWrite=_rw;
-  setFont(QFont("helvetica", RCONFIG->getSettingInt("Application:FontSize0")));
 }
 
 
@@ -101,10 +98,10 @@ RComboBox::setEditText(const QString& _txt)
   // Combo box isn't editable / 
   //   set the item from list if available:
   //
-  if(strcmp(currentText().latin1(), _txt)) {
+  if( currentText() != _txt ) {
     int i;
     for(i=0; i<count(); ++i) {
-      if(!strcmp(text(i).latin1(), _txt)) {
+      if( text(i) == _txt ) {
         setCurrentItem(i);
       }
     }
@@ -112,6 +109,28 @@ RComboBox::setEditText(const QString& _txt)
 }
 
 
+// Set a double value as text
+//
+void
+RComboBox::setValue( double _val )
+{
+  QString str;
+  str.setNum( _val, 'g', 6 );
+  setEditText( str );
+}
+
+
+
+// Set an int value as text
+//
+void
+RComboBox::setValue( int _val )
+{
+  QString str;
+  str.setNum( _val );
+  setEditText( str );
+}
+
 
 // Set the edit text from parameter ($e can be $e (Extension))
 //   (works even for non-editable comboboxes)
@@ -148,12 +167,12 @@ RComboBox::setParameter(const char* _txt)
 //   available in the list:
 //
 void 
-RComboBox::insertItem(const char* _t, int _index)
+RComboBox::insertItem(const QString& _t, int _index)
 {
   if(findItem(_t)==-1) {
     QString curText=currentText();
     QComboBox::insertItem(_t, _index);
-    setEditText(curText.latin1());
+    setEditText( curText );
   }
 }
 
@@ -163,13 +182,13 @@ RComboBox::insertItem(const char* _t, int _index)
 //   return: index of item or -1:
 //
 int  
-RComboBox::findItem(const char* _t)
+RComboBox::findItem(const QString& _t)
 {
   int ret=-1;
   int i;
   
   for(i=0; i<count(); ++i) {
-    if(!strcmp(text(i).latin1(), _t)) {
+    if( text(i) == _t ) {
       ret=i;
       break;
     }
@@ -183,13 +202,13 @@ RComboBox::findItem(const char* _t)
 // Remove item by its name
 //
 void 
-RComboBox::removeItem(const char* _t)
+RComboBox::removeItem(const QString& _t)
 {
   if(_t) {
     int i;
   
     for(i=0; i<count(); ++i) {
-      if(!strcmp(text(i).latin1(), _t)) {
+      if( text(i) == _t ) {
         removeItem(i);
       }
     }
@@ -204,6 +223,7 @@ RComboBox::removeItem(const char* _t)
 bool 
 RComboBox::fillInMachineGenerators(bool _clear)
 {
+  bool ret=false;
   RLOG("\nFill In Machine Generators");
 
   QString machPath;     // Path of machine gen. files
@@ -213,28 +233,34 @@ RComboBox::fillInMachineGenerators(bool _clear)
   //
   if(_clear) clear();
 
-  machPath = fileSearchSubdir("machines");
-  //machPath.sprintf("%s/machines", RCONFIG->getPrgDir().path().latin1());
-  machFilter = "*.cxm";
+  for( int p=1; p<=3; ++p ) {
+    machPath = fileSearchSubdir("machines", p);
 
-  // Read *.cxm files from machines diretory
-  //   fill the machines in the combo box:
-  //
-  QDir dir(machPath.data(), machFilter.data());
-  dir.setFilter(QDir::Files);
-  dir.setSorting(QDir::Name);
+    if( QFileInfo(machPath).exists() ) {
+      machFilter = "*.cxm";
 
-  const QFileInfoList *list = dir.entryInfoList();
-  if(list) {
-    QFileInfoListIterator it(*list);      // create list iterator
-    QFileInfo *fi;                        // pointer for traversing
-    while( (fi=it.current()) ) {          // for each file...
-      insertItem(fi->baseName().lower().data());
-      ++it;                               // goto next list element
+      // Read *.cxm files from machines diretory
+      //   fill the machines in the combo box:
+      //
+      QDir dir(machPath, machFilter);
+      dir.setFilter(QDir::Files);
+      dir.setSorting(QDir::Name);
+
+      QStringList machList = dir.entryList();
+      QStringList::ConstIterator machIterator;
+      QFileInfo machFileInfo;
+
+      if( machList.count()>0 ) {
+        for( machIterator=machList.begin(); machIterator!=machList.end(); ++machIterator ) {
+          machFileInfo.setFile( machPath+"/"+(*machIterator) );
+          insertItem( machFileInfo.baseName() );
+        }
+        ret=true;
+      }
     }
-    return true;
   }
-  return false;
+
+  return ret;
 }
 
 
@@ -265,7 +291,7 @@ RComboBox::fillInLayers(RGraphic* _graphic, bool _all, bool _clear)
 
     // [All Layers]:
     //
-    if(_all) insertItem(RMES(93), 0);
+    if(_all) insertItem(tr("[All Layers]"), 0);
     setCurrentItem(0);
     
     return true;
@@ -357,8 +383,8 @@ bool
 RComboBox::fillInParameters(const char* _mach, bool _layerParameters, bool _clear)
 {
   //QString machineGeneratorPath = RIni::getRIni()->getMachineGeneratorPath(_mach);
-  QString machineGeneratorPath = fileSearchFile( "machines", _mach );
-  QFile maFile(machineGeneratorPath.data());
+  QString machineGeneratorPath = fileSearchFile( "machines", QString(_mach)+".cxm" );
+  QFile maFile(machineGeneratorPath);
 
   // Read entries from mach-File:
   //
@@ -374,14 +400,14 @@ RComboBox::fillInParameters(const char* _mach, bool _layerParameters, bool _clea
     QString maLine;        // a line
     QString maSection;     // a section (e.g.: "[Standards]")
 
-    while(!maStream.eof()) {
+    while(!maStream.atEnd()) {
       maLine=maStream.readLine();
       maLine=maLine.stripWhiteSpace();
 
       // New section:
       //
       if(maLine.at(0)=='[') {
-        maSection=maLine.data();
+        maSection=maLine;
       }
       else {
         if(maSection=="[Parameter]" ||
@@ -393,7 +419,7 @@ RComboBox::fillInParameters(const char* _mach, bool _layerParameters, bool _clea
 
             slabel[0]='\0';
 
-            strGetValuesFromParameterLine(maLine.data(),
+            strGetValuesFromParameterLine(maLine.latin1(),
                                           0,
                                           0,
                                           &scode,
@@ -417,7 +443,7 @@ RComboBox::fillInParameters(const char* _mach, bool _layerParameters, bool _clea
     
     maFile.close();
 
-    setEditText(curText.latin1());
+    setEditText( curText );
     return true;
   }
   else {
@@ -432,8 +458,8 @@ RComboBox::fillInParameters(const char* _mach, bool _layerParameters, bool _clea
 bool 
 RComboBox::fillInOrders(const char* _mach, bool _clear)
 {
-  QString machineGeneratorPath = fileSearchFile( "machines", _mach );
-  QFile maFile(machineGeneratorPath.data());
+  QString machineGeneratorPath = fileSearchFile( "machines", QString(_mach)+".cxm" );
+  QFile maFile(machineGeneratorPath);
 
   // Read entries from mach-File:
   //
@@ -450,14 +476,14 @@ RComboBox::fillInOrders(const char* _mach, bool _clear)
     QString maSection;     // a section (e.g.: "[Standards]")
     char    tmpBuf[256];   // Temp buffer for order names
 
-    while(!maStream.eof()) {
+    while(!maStream.atEnd()) {
       maLine=maStream.readLine();
       maLine=maLine.stripWhiteSpace();
 
       // New section:
       //
       if(maLine.at(0)=='[') {
-        maSection=maLine.data();
+        maSection=maLine;
       }
       else {
         if(maSection=="[Code]") {
@@ -466,17 +492,17 @@ RComboBox::fillInOrders(const char* _mach, bool _clear)
           // Exclude comments and empty lines:
           //
           if(!maLine.isEmpty() &&
-             strncmp(maLine.data(), "//", 2)) {
+             maLine.left(2) != "//" ) {
                
             while(!maLine.contains('}') &&
-                  !maStream.eof()) {
-              maLine+=maStream.readLine().data();
+                  !maStream.atEnd()) {
+              maLine+=maStream.readLine();
             }
                   
             // Order Name:
             //
             tmpBuf[0]='\0';
-            sscanf(maLine.data(), 
+            sscanf(maLine.latin1(), 
                    "%255s",
                    tmpBuf);
   
@@ -491,7 +517,7 @@ RComboBox::fillInOrders(const char* _mach, bool _clear)
     
     maFile.close();
 
-    setEditText(curText.latin1());
+    setEditText( curText );
     return true;
   }
   else {
@@ -507,8 +533,8 @@ bool
 RComboBox::fillInOrderItems(QList<QString> &_order, const char* _exception, bool _clear)
 {
   QString* sord;         // pointer which walks through orders
-  QCString ord;          // Copy of ord but in old QCString style
-  char* itemPtr;         // Walk through order
+  QString ord;           // Copy of ord but in old QCString style (??)
+  const char* itemPtr;   // Walk through order
   char  item[32700];     // Contents of a single item
 
   if(_clear) clear();
@@ -516,11 +542,11 @@ RComboBox::fillInOrderItems(QList<QString> &_order, const char* _exception, bool
   if(!_order.isEmpty()) {
     for(sord=_order.first(); sord!=0; sord=_order.next()) {
     
-      ord = sord->data();
+      ord = *sord;
 
       // Walk through Items (<...>) and fill ComboBox-List:
       //
-      itemPtr = ord.data();
+      itemPtr = ord.latin1();
 
       // Step forward to '{':
       //
@@ -590,6 +616,8 @@ RComboBox::fillInOrderItems(QList<QString> &_order, const char* _exception, bool
       insertItem("<A1>");
       insertItem("<A2>");
       insertItem("<A>");
+      insertItem("<Radius>");
+      insertItem("<Diameter>");
 
       if(_exception) removeItem(_exception);
     }
@@ -617,7 +645,7 @@ RComboBox::fillInItemsFrom(RComboBox* _source, bool _clear)
     }
   }
   
-  setEditText(curText.latin1());
+  setEditText( curText );
   
   return true;
 }
@@ -626,7 +654,7 @@ RComboBox::fillInItemsFrom(RComboBox* _source, bool _clear)
 
 // Fill in items from a string
 //
-//   the items must be seperated by spaces
+//   the items must be separated by spaces
 //
 bool 
 RComboBox::fillInItemsFromString(const char* _str, bool _clear)
@@ -672,6 +700,9 @@ RComboBox::fillInIfItems(bool _clear)
 
   insertItem("poschanged1");
   insertItem("poschanged2");
+  insertItem("contourbegin");
+  insertItem("contourmiddle");
+  insertItem("contourend");
 
   return true;
 }
@@ -702,39 +733,326 @@ RComboBox::fillInFonts(bool _clear)
 bool
 RComboBox::fillInPatterns(bool _clear)
 {
+  bool ret=false;
   if(_clear) clear();
 
   //QString hatchPath = RIni::getRIni()->getProgramPath();
   //hatchPath+="/hatches";
 
-  QString hatchPath = fileSearchSubdir( "hatches" );
+  for( int p=1; p<=3; ++p ) {
+    QString hatchPath = fileSearchSubdir( "hatches", p );
 
-  QDir hatchDir(hatchPath, "*.dxf");
-  QStringList hatchList = hatchDir.entryList();
-  QStringList::ConstIterator hatchIterator;
-  QFileInfo hatchFileInfo;
+    QDir hatchDir(hatchPath, "*.dxf");
+    QStringList hatchList = hatchDir.entryList();
+    QStringList::ConstIterator hatchIterator;
+    QFileInfo hatchFileInfo;
 
-  if( hatchList.count()>0 ) {
-    for( hatchIterator=hatchList.begin(); hatchIterator!=hatchList.end(); ++hatchIterator ) {
-      hatchFileInfo.setFile( hatchPath+"/"+(*hatchIterator) );
-      insertItem( hatchFileInfo.baseName() );
+    if( hatchList.count()>0 ) {
+      for( hatchIterator=hatchList.begin(); hatchIterator!=hatchList.end(); ++hatchIterator ) {
+        hatchFileInfo.setFile( hatchPath+"/"+(*hatchIterator) );
+        insertItem( hatchFileInfo.baseName() );
+      }
+      ret=true;
     }
-    return true;
   }
 
-  return false;
+  return ret;
 }
 
+
+
+// Fill in units:
+//
+bool
+RComboBox::fillInUnits(bool _clear)
+{
+  if(_clear) clear();
+
+  insertItem( "None" );
+  insertItem( "Inch" );
+  insertItem( "Foot" );
+  insertItem( "Mile" );
+  insertItem( "Millimeter" );
+  insertItem( "Centimeter" );
+  insertItem( "Meter" );
+  insertItem( "Kilometer" );
+  insertItem( "Microinch" );
+  insertItem( "Mil" );
+  insertItem( "Yard" );
+  insertItem( "Angstrom" );
+  insertItem( "Nanometer" );
+  insertItem( "Micron" );
+  insertItem( "Decimeter" );
+  insertItem( "Decameter" );
+  insertItem( "Hectometer" );
+  insertItem( "Gigameter" );
+  insertItem( "Astro" );
+  insertItem( "Lightyear" );
+  insertItem( "Parsec" );
+
+  return true;
+}
+
+
+// Fill in metric/english exactness
+bool
+RComboBox::fillInExactness(bool _metric, bool _clear)
+{
+  if(_clear) clear();
+
+  if(_metric) {
+    insertItem( "1" );
+    insertItem( "0.1" );
+    insertItem( "0.01" );
+    insertItem( "0.001" );
+    insertItem( "0.0001" );
+    insertItem( "0.00001" );
+    insertItem( "0.000001" );
+  }
+  else {
+    insertItem( "1/2" );
+    insertItem( "1/4" );
+    insertItem( "1/8" );
+    insertItem( "1/16" );
+    insertItem( "1/32" );
+    insertItem( "1/64" );
+    insertItem( "1/128" );
+    insertItem( "1/256" );
+    insertItem( "1/512" );
+    insertItem( "1/1024" );
+  }
+
+  return true;
+}
+
+
+// Fill in metric/english scales
+bool
+RComboBox::fillInScale(bool _metric, ScaleType _type, bool _clear )
+{
+  if(_clear) clear();
+
+  if( _metric || _type==Absolute ) {
+    insertItem( "100000:1" );
+    insertItem( "75000:1" );
+    insertItem( "50000:1" );
+    insertItem( "25000:1" );
+    insertItem( "10000:1" );
+    insertItem( "7500:1" );
+    insertItem( "5000:1" );
+    insertItem( "2500:1" );
+    insertItem( "2000:1" );
+    insertItem( "1000:1" );
+    insertItem( "500:1" );
+    insertItem( "200:1" );
+    insertItem( "100:1" );
+    insertItem( "75:1" );
+    insertItem( "50:1" );
+    insertItem( "20:1" );
+    insertItem( "10:1" );
+    insertItem( "5:1" );
+    insertItem( "2:1" );
+    insertItem( "1:1" );
+    insertItem( "1:2" );
+    insertItem( "1:5" );
+    insertItem( "1:10" );
+    insertItem( "1:20" );
+    insertItem( "1:25" );
+    insertItem( "1:50" );
+    insertItem( "1:75" );
+    insertItem( "1:100" );
+    insertItem( "1:200" );
+    insertItem( "1:500" );
+    insertItem( "1:1000" );
+    insertItem( "1:2000" );
+    insertItem( "1:2500" );
+    insertItem( "1:5000" );
+    insertItem( "1:7500" );
+    insertItem( "1:10000" );
+    insertItem( "1:25000" );
+    insertItem( "1:50000" );
+    insertItem( "1:75000" );
+    insertItem( "1:100000" );
+  }
+  else {
+    if( _type==Engineering ) {
+      insertItem( "1\" = 1\"" );
+      insertItem( "1\" = 2\"" );
+      insertItem( "1\" = 4\"" );
+      insertItem( "1\" = 1'" );
+      insertItem( "1\" = 5'" );
+      insertItem( "1\" = 10'" );
+      insertItem( "1\" = 20'" );
+      insertItem( "1\" = 30'" );
+      insertItem( "1\" = 40'" );
+      insertItem( "1\" = 50'" );
+      insertItem( "1\" = 60'" );
+      insertItem( "1\" = 80'" );
+      insertItem( "1\" = 100'" );
+      insertItem( "1\" = 200'" );
+      insertItem( "1\" = 300'" );
+      insertItem( "1\" = 400'" );
+      insertItem( "1\" = 500'" );
+      insertItem( "1\" = 1000'" );
+      insertItem( "1\" = 2000'" );
+    }
+    else if( _type==Architectural ) {
+      insertItem( "1\" = 1\"" );
+      insertItem( "6\" = 1'-0\"" );
+      insertItem( "3\" = 1'-0\"" );
+      insertItem( "3/2\" = 1'-0\"" );
+      insertItem( "1\" = 1'-0\"" );
+      insertItem( "3/4\" = 1'-0\"" );
+      insertItem( "1/2\" = 1'-0\"" );
+      insertItem( "3/6\" = 1'-0\"" );
+      insertItem( "1/4\" = 1'-0\"" );
+      insertItem( "3/16\" = 1'-0\"" );
+      insertItem( "1/8\" = 1'-0\"" );
+      insertItem( "3/32\" = 1'-0\"" );
+      insertItem( "1/16\" = 1'-0\"" );
+      insertItem( "1/32\" = 1'-0\"" );
+    }
+  }
+
+  return true;
+}
+
+
+/** Fill in Scale types
+*/
+bool
+RComboBox::fillInScaleTypes(bool _metric, bool _clear)
+{
+  if(_clear) clear();
+
+  if(_metric) {
+    insertItem( "Absolute" );
+  }
+  else {
+    insertItem( "Absolute" );
+    insertItem( "Engineering" );
+    insertItem( "Architectural" );
+  }
+
+  return true;
+}
+
+
+/** Fill in Paper sizes
+*/
+bool
+RComboBox::fillInPageFormats(bool _clear)
+{
+  if(_clear) clear();
+
+  insertItem( "User" );
+  insertItem( "Letter" );
+  insertItem( "Legal" );
+  insertItem( "Executive" );
+  insertItem( "A0" );
+  insertItem( "A1" );
+  insertItem( "A2" );
+  insertItem( "A3" );
+  insertItem( "A4" );
+  insertItem( "A5" );
+  insertItem( "A6" );
+  insertItem( "A7" );
+  insertItem( "A8" );
+  insertItem( "A9" );
+  insertItem( "A10" );
+  insertItem( "B0" );
+  insertItem( "B1" );
+  insertItem( "B2" );
+  insertItem( "B3" );
+  insertItem( "B4" );
+  insertItem( "B5" );
+  insertItem( "B6" );
+  insertItem( "B7" );
+  insertItem( "B8" );
+  insertItem( "B9" );
+  insertItem( "B10" );
+  insertItem( "C0" );
+  insertItem( "C1" );
+  insertItem( "C2" );
+  insertItem( "C3" );
+  insertItem( "C4" );
+  insertItem( "C6" );
+  insertItem( "C7" );
+  insertItem( "C8" );
+  insertItem( "C9" );
+  insertItem( "C10" );
+  insertItem( "C5E" );
+  insertItem( "Comm10E" );
+  insertItem( "DLE" );
+  insertItem( "Folio" );
+  insertItem( "Ledger" );
+  insertItem( "Tabloid" );
+  insertItem( "NPageSize" );
+
+  return true;
+}
+
+
+/** Fill in Page orientations
+*/
+bool
+RComboBox::fillInPageOrientations(bool _clear)
+{
+  if(_clear) clear();
+
+  insertItem( "Portrait" );
+  insertItem( "Landscape" );
+
+  return true;
+}
+
+
+/** Fill in Charsets
+*/
+bool
+RComboBox::fillInCharsets(bool _clear)
+{
+  if(_clear) clear();
+
+  insertItem( "AnyCharSet" );
+  insertItem( "Latin1" );
+  insertItem( "Latin2" );
+  insertItem( "Latin3" );
+  insertItem( "Latin4" );
+  insertItem( "Latin5" );
+  insertItem( "Latin6" );
+  insertItem( "Latin7" );
+  insertItem( "Latin8" );
+  insertItem( "Latin9" );
+  insertItem( "ISO-8859-1" );
+  insertItem( "ISO-8859-2" );
+  insertItem( "ISO-8859-3" );
+  insertItem( "ISO-8859-4" );
+  insertItem( "ISO-8859-5" );
+  insertItem( "ISO-8859-6" );
+  insertItem( "ISO-8859-7" );
+  insertItem( "ISO-8859-8" );
+  insertItem( "ISO-8859-9" );
+  insertItem( "ISO-8859-10" );
+  insertItem( "ISO-8859-11" );
+  insertItem( "ISO-8859-12" );
+  insertItem( "ISO-8859-13" );
+  insertItem( "ISO-8859-14" );
+  insertItem( "ISO-8859-15" );
+  insertItem( "KOI8-R" );
+  insertItem( "Set-Ja" );
+  insertItem( "Set-1" );
+  insertItem( "Set-Ko" );
+  insertItem( "Set-Th-TH" );
+  insertItem( "Set-Zh" );
+  insertItem( "Set-Zh-TW" );
+  insertItem( "Set-N" );
+  insertItem( "Unicode" );
+
+  return true;
+}
+
+
+
+
 // EOF
-
-
-
-
-
-
-
-
-
-
-
-
