@@ -23,14 +23,15 @@ class RGraphic;
 
 class RFileCxf : public RFileBase  {
 public:
-  RFileCxf(const char* _name, RGraphic* _graphic);
+  RFileCxf(const QString& _name, RGraphic* _graphic);
   ~RFileCxf();
 
   bool load();
   bool readFromBuffer();
-
   bool save();
 
+  void convertToFont();
+
 private:
   RGraphic* graphic;
   int       numElements;
