@@ -11,10 +11,10 @@
 #define RHATCHDIALOG_H
 
 #include <qdialog.h>
+#include <qlabel.h>
 #include <qtooltip.h>
 #include <qpushbutton.h>
 
-#include "rlabel.h"
 #include "rcombobox.h"
 
 #define DEF_HATCHDLG_WIDTH  256
@@ -28,22 +28,22 @@
 class RHatchDialog : public QDialog  {
   Q_OBJECT
 public:
-	RHatchDialog(const char* _caption,
-	             const char* _label,
+	RHatchDialog(const QString& _caption,
+	             const QString& _label,
                QWidget* _parent=0);
 
 	~RHatchDialog();
 	
 	
 	QString getPattern();
-	float getFactor();
+	double getFactor();
 	
 private:
   QPushButton* bOk;
   QPushButton* bCancel;
   QPushButton* bHelp;
 
-  RLabel*      lText;
+  QLabel*      lText;
   RComboBox*   cbPattern;
   RComboBox*   cbFactor;
 };
