@@ -22,6 +22,9 @@ RLayer::RLayer()
 {
   name="";
   number=-1;
+  color=Qt::black;
+  width=0;
+  style=Qt::SolidLine;
 }
 
 
