@@ -21,7 +21,7 @@
 class RListBoxItem : public QListBoxItem
 {
 public:
-  RListBoxItem(const char* _text, const QPixmap _pixmap);
+  RListBoxItem(const QString& _text, const QPixmap _pixmap);
   ~RListBoxItem();
 
   virtual const QPixmap* pixmap() const { return &pm; }
