@@ -42,7 +42,7 @@ public:
 
   void   log(const char* _log);
   void   log(int _log);
-  void   log(float _log);
+  void   log(double _log);
   void   log(char _log);
 
 #ifndef DEF_SOLARIS
