@@ -26,6 +26,7 @@ public:
   RMultiLineEdit(QWidget* _parent=0, const char* _name=0);
   ~RMultiLineEdit();
 
+	void keyPressEvent( QKeyEvent *e );
   
   /*! Load a file. Ask User for a Filename */
   //
@@ -35,7 +36,7 @@ public:
       \param _name file name
       \return true if loading was successful
   */
-  bool loadFile(const char* _name);
+  bool loadFile(const QString& _name);
   
   /*! Save the text in a file. Ask User for a Filename */
   //
@@ -45,7 +46,7 @@ public:
       \param _name file name
       \return true if loading was successful
   */
-  bool saveFile(const char* _name);
+  bool saveFile(const QString& _name);
 
 protected:
   void resizeEvent(QResizeEvent *_ev);
