@@ -22,15 +22,20 @@ class RPainter : public QPainter
 {
 public:
   RPainter();
-  RPainter(const QPaintDevice* _pDev);
+  RPainter( const QPaintDevice* _pDev );
   ~RPainter();
 
-  void drawExactArc(float _cx, float _cy, 
-                    float _cr,
-                    float _a1, float _a2,
-                    int   _x1, int   _y1,
-                    int   _x2, int   _y2,
-                    bool _reversed);
+  void drawExactArc( double _cx, double _cy,
+                     double _cr,
+                     double _a1, double _a2,
+                     int   _x1, int   _y1,
+                     int   _x2, int   _y2,
+                     bool _reversed );
+
+  void drawStyleLine( int _x1, int _y1,
+                      int _x2, int _y2,
+                      int _width=1,
+                      PenStyle _style=SolidLine );
     
 private:
 
