@@ -33,7 +33,7 @@ public:
       \param _newLine Allow new Line
       \param _name Name
   */
-  RToolBar(const char* _label, QMainWindow* _parent,
+  RToolBar(const QString& _label, QMainWindow* _parent,
            QMainWindow::ToolBarDock _dock= QMainWindow::Top, 
            bool _newLine = false,
            const char* _name=0);
