@@ -11,16 +11,16 @@
 
 #include "xpm/simstart.xpm"
 #include "xpm/simsmooth.xpm"
-#include "xpm/simpointing.xpm"
+//#include "xpm/simpointing.xpm"
 
 #include "xpm/info.xpm"
-#include "xpm/edit.xpm"
-#include "xpm/layerlist.xpm"
+//#include "xpm/edit.xpm"
+//#include "xpm/layerlist.xpm"
 
 #include "xpm/simbroken.xpm"
 #include "xpm/simrapidmove.xpm"
 #include "xpm/simdetails.xpm"
-#include "xpm/simgrid.xpm"
+//#include "xpm/simgrid.xpm"
 
 #endif
 
