@@ -18,7 +18,7 @@
 
 #include <qdialog.h>
 
-class RLabel;
+class QLabel;
 
 /*! Dialog for messages with OK/Cancel Button
 */
@@ -33,9 +33,9 @@ public:
       \param _parent The parent widget
       \param _name  Name
   */
-  RYesNoDialog(const char* _label,
-               const char* _but1,
-               const char* _but2,
+  RYesNoDialog(const QString& _label,
+               const QString& _but1,
+               const QString& _but2,
                QWidget* _parent=0, 
                const char* _name=0);
   /*! Destructor
@@ -52,7 +52,7 @@ private:
 
   /*! The label
   */
-  RLabel*      lText;
+  QLabel*      lText;
   
 };
 
